@@ -1,4 +1,4 @@
-/* $Id: dict.c,v 1.11 2000/10/18 23:33:33 rbrady Exp $ */
+/* $Id: dict.c,v 1.12 2001/02/15 12:38:15 jirka Exp $ */
 /* -*- mode: c; style: k&r; c-basic-offset: 4 -*- */
 
 /*
@@ -92,23 +92,23 @@ static int dict_write (dict_context_t *context, GString *str)
 static void
 dict_command_done (dict_command_t *command) 
 {
+    dict_context_t *context = command->context;
+
+    command->context = NULL;
     command->state = S_DONE;
     
-    if (command->context) {
-        command->context->command = NULL;
+    if (context) {
+        context->command = NULL;
         if (command->temp_context) {
-            if (command->context->channel && command->cmd != C_DISCONNECT) {
+            if (context->channel && command->cmd != C_DISCONNECT) {
                 dict_command_t *sec_cmd = dict_disconnect_command_new ();
                 sec_cmd->temp_context = TRUE;
-                dict_command_invoke (sec_cmd, command->context);
+                dict_command_invoke (sec_cmd, context);
+            } else {
+                dict_context_destroy (context);
             }
-            else {
-                dict_context_destroy (command->context);
-            }
-        }
+	}
     }
-    
-    command->context = NULL;
 }
 
 /* dict_cycle_buffer ()
@@ -177,7 +177,7 @@ static char *dict_read_line (dict_context_t *context) {
     start_ptr = context->read_ptr;
     context->read_ptr = end_ptr + 2;
     
-    return start_ptr;
+    return g_strdup (start_ptr);
 }
 
 /* data_notify_match (line)
@@ -354,6 +354,7 @@ static void data_notify_define (dict_context_t *context, char *line)
             new_res->free_name = new_res->free_desc = TRUE;
             
             g_string_free (command->def, FALSE);
+	    command->def = NULL;
             
             command->res_tail = g_list_append (command->res_tail, new_res);
             if (!command->res_list) command->res_list = command->res_tail;
@@ -459,6 +460,7 @@ static void data_notify_show_strat (dict_context_t *context,
 {
     DictStatusCode status_code;
     int num_found;
+    char *newline;
     char *name, *desc;
     dict_res_t *new_res;
     dict_command_t *command;
@@ -505,6 +507,7 @@ static void data_notify_show_strat (dict_context_t *context,
             command->state = S_STATUS;
         }
         else {
+	    newline = line = g_strdup (line);
             name = line;
             line = strchr (line, ' ');
             *line = '\0'; line++;
@@ -516,6 +519,8 @@ static void data_notify_show_strat (dict_context_t *context,
             new_res = dict_res_new (g_strdup (name), g_strdup (desc));
             new_res->free_name = TRUE;
             new_res->free_desc = TRUE;
+
+	    g_free (newline);
             
             command->res_tail = 
 		g_list_append (command->res_tail, new_res);
@@ -605,6 +610,12 @@ static gboolean dict_data_notify (GIOChannel *channel, GIOCondition cond,
     dict_context_t *context;
     
     context = (dict_context_t *) data;
+
+    /* HAAAAAAAAAAACK, we never free context because there is
+     * some sort of corruption or what not and this gets called,
+     * even after connection was closed */
+    if (context->channel == NULL)
+	    return FALSE;
     
     if (cond == G_IO_IN) {
         context->read_cycle_done = FALSE;
@@ -614,6 +625,7 @@ static gboolean dict_data_notify (GIOChannel *channel, GIOCondition cond,
 		g_error ("Data received in ground state");
             else
 		context->command->raw_data_notify_cb (context, line);
+	    g_free (line);
         }
     }
     else if (cond == G_IO_ERR) {
@@ -623,6 +635,7 @@ static gboolean dict_data_notify (GIOChannel *channel, GIOCondition cond,
 					       _("Cannot connect to server"),
 					       context->command->user_data);
         dict_disconnect (context);
+	return FALSE;
     }
     
     return TRUE;
@@ -643,8 +656,8 @@ dict_context_t *dict_context_new (gchar *server, gushort port)
     dict_context_t *context;
 
     context = g_new0 (dict_context_t, 1);
-    context->hostname =
-	(server != NULL) ? server : DICT_DEFAULT_SERVER;
+    context->hostname = g_strdup
+	    ((server != NULL) ? server : DICT_DEFAULT_SERVER);
     context->hostinfo = NULL;
     context->sockaddr.sin_family = AF_INET;
     context->sockaddr.sin_port =
@@ -669,7 +682,7 @@ dict_context_t *dict_context_clone (dict_context_t *context)
     
     bcopy (&context->sockaddr, &new_context->sockaddr,
 	   sizeof (context->sockaddr));
-    new_context->hostname = context->hostname;
+    new_context->hostname = g_strdup (context->hostname);
     new_context->hostinfo = context->hostinfo;
     new_context->read_ptr = new_context->write_ptr =
 	new_context->read_buf;
@@ -687,7 +700,11 @@ void dict_context_destroy (dict_context_t *context)
     g_return_if_fail (context != NULL);
 
     dict_disconnect (context);
-    g_free (context);
+    g_free (context->hostname);
+    context->hostname = NULL;
+    /* FOOOOOOOO, HAAAAAAAAAAACK, the notify handler still gets called,
+     * I do not understand this, this keeps it from dieing */
+    /*g_free (context);*/
 }
 
 /* dict_connect (context)
@@ -738,11 +755,16 @@ void dict_disconnect (dict_context_t *context)
 {
     g_return_if_fail (context != NULL);
 
-    if (!context->channel) return;
-    
-    g_source_remove (context->source_id);
-    g_io_channel_close (context->channel);
-    context->channel = NULL;
+    if (context->source_id > 0) {
+	    g_source_remove (context->source_id);
+	    context->source_id = 0;
+    }
+
+    if (context->channel != NULL) {
+	    g_io_channel_close (context->channel);
+	    g_io_channel_unref (context->channel);
+	    context->channel = NULL;
+    }
 }
 
 /* dict_command_new ()
@@ -986,7 +1008,7 @@ int dict_command_invoke (dict_command_t *command,
      * are going to use
      */
      
-    else {
+    else if (context->command == NULL) {
         command->context = context;
     }
     
@@ -1039,6 +1061,8 @@ gint dict_context_do_dns_lookup (dict_context_t *context)
 
     if (context->hostinfo != NULL) return 0;
 
+    if (context->hostname == NULL) return -1;
+
     if ((context->hostinfo = gethostbyname (context->hostname)) != NULL) {
 	bcopy(context->hostinfo->h_addr, &context->sockaddr.sin_addr,
 	      context->hostinfo->h_length);
