@@ -177,7 +177,9 @@ param_desc_ingest(const char *fn)
   ||  !doc->root || doc->root->type != XML_ELEMENT_NODE
   ||  !streq(doc->root->name, "stripchart") )
     {
-      error("Can't parse parameter file \"%s\".\n", fn);
+      static int complaints;
+      if (complaints++ == 0)
+	error("Can't parse parameter file \"%s\".\n", fn);
       return NULL;
     }
 
@@ -446,7 +448,7 @@ on_color_set(GnomeColorPicker *picker,
     if (GNOME_COLOR_PICKER(page->color[cnum]) == picker)
       break;
 
-  if (cnum < page->colors)
+  if (cnum < page->colors && page->strip_data && page->pen_data)
     {
       set_color(page->strip_data, color_name, cnum);
       set_color(page->pen_data, color_name, cnum);
